netapp_ontap.models.datacollection_search API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.datacollection_search`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DatacollectionSearchSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DatacollectionSearch object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `chunk: str GET`

    The content of the chunk.

  `entity: DatacollectionEntity GET POST PATCH`

    The entity field of the datacollection_search.

  `index: Size GET`

    The index of the chunk in the result.

    Example: 1

  `score: Dict GET`

    Similarity score of the chunk with the prompt that was searched for.

    Example: 0.9